==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/guardduty/kotlin/OrganizationConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.guardduty.kotlin

import com.pulumi.aws.guardduty.OrganizationConfigurationArgs.builder
import com.pulumi.aws.guardduty.kotlin.inputs.OrganizationConfigurationDatasourcesArgs
import com.pulumi.aws.guardduty.kotlin.inputs.OrganizationConfigurationDatasourcesArgsBuilder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.Deprecated
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Manages the GuardDuty Organization Configuration in the current AWS Region. The AWS account utilizing this resource must have been assigned as a delegated Organization administrator account, e.g., via the `aws.guardduty.OrganizationAdminAccount` resource. More information about Organizations support in GuardDuty can be found in the [GuardDuty User Guide](https://docs.aws.amazon.com/guardduty/latest/ug/guardduty_organizations.html).
 * > **NOTE:** This is an advanced resource. The provider will automatically assume management of the GuardDuty Organization Configuration without import and perform no actions on removal from the resource configuration.
 * ## Example Usage
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.aws.guardduty.Detector;
 * import com.pulumi.aws.guardduty.DetectorArgs;
 * import com.pulumi.aws.guardduty.OrganizationConfiguration;
 * import com.pulumi.aws.guardduty.OrganizationConfigurationArgs;
 * import com.pulumi.aws.guardduty.inputs.OrganizationConfigurationDatasourcesArgs;
 * import com.pulumi.aws.guardduty.inputs.OrganizationConfigurationDatasourcesS3LogsArgs;
 * import com.pulumi.aws.guardduty.inputs.OrganizationConfigurationDatasourcesKubernetesArgs;
 * import com.pulumi.aws.guardduty.inputs.OrganizationConfigurationDatasourcesKubernetesAuditLogsArgs;
 * import com.pulumi.aws.guardduty.inputs.OrganizationConfigurationDatasourcesMalwareProtectionArgs;
 * import com.pulumi.aws.guardduty.inputs.OrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindingsArgs;
 * import com.pulumi.aws.guardduty.inputs.OrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumesArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var exampleDetector = new Detector("exampleDetector", DetectorArgs.builder()
 *             .enable(true)
 *             .build());
 *         var exampleOrganizationConfiguration = new OrganizationConfiguration("exampleOrganizationConfiguration", OrganizationConfigurationArgs.builder()
 *             .autoEnableOrganizationMembers("ALL")
 *             .detectorId(exampleDetector.id())
 *             .datasources(OrganizationConfigurationDatasourcesArgs.builder()
 *                 .s3Logs(OrganizationConfigurationDatasourcesS3LogsArgs.builder()
 *                     .autoEnable(true)
 *                     .build())
 *                 .kubernetes(OrganizationConfigurationDatasourcesKubernetesArgs.builder()
 *                     .auditLogs(OrganizationConfigurationDatasourcesKubernetesAuditLogsArgs.builder()
 *                         .enable(true)
 *                         .build())
 *                     .build())
 *                 .malwareProtection(OrganizationConfigurationDatasourcesMalwareProtectionArgs.builder()
 *                     .scanEc2InstanceWithFindings(OrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindingsArgs.builder()
 *                         .ebsVolumes(OrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumesArgs.builder()
 *                             .autoEnable(true)
 *                             .build())
 *                         .build())
 *                     .build())
 *                 .build())
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * Using `pulumi import`, import GuardDuty Organization Configurations using the GuardDuty Detector ID. For example:
 * ```sh
 *  $ pulumi import aws:guardduty/organizationConfiguration:OrganizationConfiguration example 00b00fd5aecc0ab60a708659477e9617
 * ```
 * @property autoEnable *Deprecated:* Use `auto_enable_organization_members` instead. When this setting is enabled, all new accounts that are created in, or added to, the organization are added as a member accounts of the organization’s GuardDuty delegated administrator and GuardDuty is enabled in that AWS Region.
 * @property autoEnableOrganizationMembers Indicates the auto-enablement configuration of GuardDuty for the member accounts in the organization. Valid values are `ALL`, `NEW`, `NONE`.
 * @property datasources Configuration for the collected datasources.
 * @property detectorId The detector ID of the GuardDuty account.
 */
public data class OrganizationConfigurationArgs(
    @Deprecated(
        message = """
  Use auto_enable_organization_members instead
  """,
    )
    public val autoEnable: Output<Boolean>? = null,
    public val autoEnableOrganizationMembers: Output<String>? = null,
    public val datasources: Output<OrganizationConfigurationDatasourcesArgs>? = null,
    public val detectorId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.guardduty.OrganizationConfigurationArgs> {
    override fun toJava(): com.pulumi.aws.guardduty.OrganizationConfigurationArgs =
        com.pulumi.aws.guardduty.OrganizationConfigurationArgs.builder()
            .autoEnable(autoEnable?.applyValue({ args0 -> args0 }))
            .autoEnableOrganizationMembers(autoEnableOrganizationMembers?.applyValue({ args0 -> args0 }))
            .datasources(datasources?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .detectorId(detectorId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [OrganizationConfigurationArgs].
 */
@PulumiTagMarker
public class OrganizationConfigurationArgsBuilder internal constructor() {
    private var autoEnable: Output<Boolean>? = null

    private var autoEnableOrganizationMembers: Output<String>? = null

    private var datasources: Output<OrganizationConfigurationDatasourcesArgs>? = null

    private var detectorId: Output<String>? = null

    /**
     * @param value *Deprecated:* Use `auto_enable_organization_members` instead. When this setting is enabled, all new accounts that are created in, or added to, the organization are added as a member accounts of the organization’s GuardDuty delegated administrator and GuardDuty is enabled in that AWS Region.
     */
    @Deprecated(
        message = """
  Use auto_enable_organization_members instead
  """,
    )
    @JvmName("jjuptlktkjpncwfb")
    public suspend fun autoEnable(`value`: Output<Boolean>) {
        this.autoEnable = value
    }

    /**
     * @param value Indicates the auto-enablement configuration of GuardDuty for the member accounts in the organization. Valid values are `ALL`, `NEW`, `NONE`.
     */
    @JvmName("ncmgkrqvepqrglnp")
    public suspend fun autoEnableOrganizationMembers(`value`: Output<String>) {
        this.autoEnableOrganizationMembers = value
    }

    /**
     * @param value Configuration for the collected datasources.
     */
    @JvmName("ebxrxcjxyesuguyy")
    public suspend fun datasources(`value`: Output<OrganizationConfigurationDatasourcesArgs>) {
        this.datasources = value
    }

    /**
     * @param value The detector ID of the GuardDuty account.
     */
    @JvmName("owmvslwvmnagnaph")
    public suspend fun detectorId(`value`: Output<String>) {
        this.detectorId = value
    }

    /**
     * @param value *Deprecated:* Use `auto_enable_organization_members` instead. When this setting is enabled, all new accounts that are created in, or added to, the organization are added as a member accounts of the organization’s GuardDuty delegated administrator and GuardDuty is enabled in that AWS Region.
     */
    @Deprecated(
        message = """
  Use auto_enable_organization_members instead
  """,
    )
    @JvmName("jdhdhiwtcrlpanjb")
    public suspend fun autoEnable(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.autoEnable = mapped
    }

    /**
     * @param value Indicates the auto-enablement configuration of GuardDuty for the member accounts in the organization. Valid values are `ALL`, `NEW`, `NONE`.
     */
    @JvmName("jnnlcvbvjvmvxpwk")
    public suspend fun autoEnableOrganizationMembers(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.autoEnableOrganizationMembers = mapped
    }

    /**
     * @param value Configuration for the collected datasources.
     */
    @JvmName("akpxhyghvxaqjvjh")
    public suspend fun datasources(`value`: OrganizationConfigurationDatasourcesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.datasources = mapped
    }

    /**
     * @param argument Configuration for the collected datasources.
     */
    @JvmName("wkfrvkgtkjlwvywh")
    public suspend
    fun datasources(argument: suspend OrganizationConfigurationDatasourcesArgsBuilder.() -> Unit) {
        val toBeMapped = OrganizationConfigurationDatasourcesArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.datasources = mapped
    }

    /**
     * @param value The detector ID of the GuardDuty account.
     */
    @JvmName("mxhpimuggcbtejab")
    public suspend fun detectorId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.detectorId = mapped
    }

    internal fun build(): OrganizationConfigurationArgs = OrganizationConfigurationArgs(
        autoEnable = autoEnable,
        autoEnableOrganizationMembers = autoEnableOrganizationMembers,
        datasources = datasources,
        detectorId = detectorId,
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/guardduty/kotlin/OrganizationConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.guardduty.kotlin

import com.pulumi.aws.guardduty.OrganizationConfigurationArgs.builder
import com.pulumi.aws.guardduty.kotlin.inputs.OrganizationConfigurationDatasourcesArgs
import com.pulumi.aws.guardduty.kotlin.inputs.OrganizationConfigurationDatasourcesArgsBuilder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.Deprecated
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Manages the GuardDuty Organization Configuration in the current AWS Region. The AWS account utilizing this resource must have been assigned as a delegated Organization administrator account, e.g., via the `aws.guardduty.OrganizationAdminAccount` resource. More information about Organizations support in GuardDuty can be found in the [GuardDuty User Guide](https://docs.aws.amazon.com/guardduty/latest/ug/guardduty_organizations.html).
 * > **NOTE:** This is an advanced resource. The provider will automatically assume management of the GuardDuty Organization Configuration without import and perform no actions on removal from the resource configuration.
 * ## Example Usage
 * <!--Start PulumiCodeChooser -->
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 * const example = new aws.guardduty.Detector("example", {enable: true});
 * const exampleOrganizationConfiguration = new aws.guardduty.OrganizationConfiguration("example", {
 *     autoEnableOrganizationMembers: "ALL",
 *     detectorId: example.id,
 *     datasources: {
 *         s3Logs: {
 *             autoEnable: true,
 *         },
 *         kubernetes: {
 *             auditLogs: {
 *                 enable: true,
 *             },
 *         },
 *         malwareProtection: {
 *             scanEc2InstanceWithFindings: {
 *                 ebsVolumes: {
 *                     autoEnable: true,
 *                 },
 *             },
 *         },
 *     },
 * });
 * ```
 * ```python
 * import pulumi
 * import pulumi_aws as aws
 * example = aws.guardduty.Detector("example", enable=True)
 * example_organization_configuration = aws.guardduty.OrganizationConfiguration("example",
 *     auto_enable_organization_members="ALL",
 *     detector_id=example.id,
 *     datasources={
 *         "s3_logs": {
 *             "auto_enable": True,
 *         },
 *         "kubernetes": {
 *             "audit_logs": {
 *                 "enable": True,
 *             },
 *         },
 *         "malware_protection": {
 *             "scan_ec2_instance_with_findings": {
 *                 "ebs_volumes": {
 *                     "auto_enable": True,
 *                 },
 *             },
 *         },
 *     })
 * ```
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using Aws = Pulumi.Aws;
 * return await Deployment.RunAsync(() =>
 * {
 *     var example = new Aws.GuardDuty.Detector("example", new()
 *     {
 *         Enable = true,
 *     });
 *     var exampleOrganizationConfiguration = new Aws.GuardDuty.OrganizationConfiguration("example", new()
 *     {
 *         AutoEnableOrganizationMembers = "ALL",
 *         DetectorId = example.Id,
 *         Datasources = new Aws.GuardDuty.Inputs.OrganizationConfigurationDatasourcesArgs
 *         {
 *             S3Logs = new Aws.GuardDuty.Inputs.OrganizationConfigurationDatasourcesS3LogsArgs
 *             {
 *                 AutoEnable = true,
 *             },
 *             Kubernetes = new Aws.GuardDuty.Inputs.OrganizationConfigurationDatasourcesKubernetesArgs
 *             {
 *                 AuditLogs = new Aws.GuardDuty.Inputs.OrganizationConfigurationDatasourcesKubernetesAuditLogsArgs
 *                 {
 *                     Enable = true,
 *                 },
 *             },
 *             MalwareProtection = new Aws.GuardDuty.Inputs.OrganizationConfigurationDatasourcesMalwareProtectionArgs
 *             {
 *                 ScanEc2InstanceWithFindings = new Aws.GuardDuty.Inputs.OrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindingsArgs
 *                 {
 *                     EbsVolumes = new Aws.GuardDuty.Inputs.OrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumesArgs
 *                     {
 *                         AutoEnable = true,
 *                     },
 *                 },
 *             },
 *         },
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-aws/sdk/v6/go/aws/guardduty"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		example, err := guardduty.NewDetector(ctx, "example", &guardduty.DetectorArgs{
 * 			Enable: pulumi.Bool(true),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		_, err = guardduty.NewOrganizationConfiguration(ctx, "example", &guardduty.OrganizationConfigurationArgs{
 * 			AutoEnableOrganizationMembers: pulumi.String("ALL"),
 * 			DetectorId:                    example.ID(),
 * 			Datasources: &guardduty.OrganizationConfigurationDatasourcesArgs{
 * 				S3Logs: &guardduty.OrganizationConfigurationDatasourcesS3LogsArgs{
 * 					AutoEnable: pulumi.Bool(true),
 * 				},
 * 				Kubernetes: &guardduty.OrganizationConfigurationDatasourcesKubernetesArgs{
 * 					AuditLogs: &guardduty.OrganizationConfigurationDatasourcesKubernetesAuditLogsArgs{
 * 						Enable: pulumi.Bool(true),
 * 					},
 * 				},
 * 				MalwareProtection: &guardduty.OrganizationConfigurationDatasourcesMalwareProtectionArgs{
 * 					ScanEc2InstanceWithFindings: &guardduty.OrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindingsArgs{
 * 						EbsVolumes: &guardduty.OrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumesArgs{
 * 							AutoEnable: pulumi.Bool(true),
 * 						},
 * 					},
 * 				},
 * 			},
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.aws.guardduty.Detector;
 * import com.pulumi.aws.guardduty.DetectorArgs;
 * import com.pulumi.aws.guardduty.OrganizationConfiguration;
 * import com.pulumi.aws.guardduty.OrganizationConfigurationArgs;
 * import com.pulumi.aws.guardduty.inputs.OrganizationConfigurationDatasourcesArgs;
 * import com.pulumi.aws.guardduty.inputs.OrganizationConfigurationDatasourcesS3LogsArgs;
 * import com.pulumi.aws.guardduty.inputs.OrganizationConfigurationDatasourcesKubernetesArgs;
 * import com.pulumi.aws.guardduty.inputs.OrganizationConfigurationDatasourcesKubernetesAuditLogsArgs;
 * import com.pulumi.aws.guardduty.inputs.OrganizationConfigurationDatasourcesMalwareProtectionArgs;
 * import com.pulumi.aws.guardduty.inputs.OrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindingsArgs;
 * import com.pulumi.aws.guardduty.inputs.OrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumesArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var example = new Detector("example", DetectorArgs.builder()
 *             .enable(true)
 *             .build());
 *         var exampleOrganizationConfiguration = new OrganizationConfiguration("exampleOrganizationConfiguration", OrganizationConfigurationArgs.builder()
 *             .autoEnableOrganizationMembers("ALL")
 *             .detectorId(example.id())
 *             .datasources(OrganizationConfigurationDatasourcesArgs.builder()
 *                 .s3Logs(OrganizationConfigurationDatasourcesS3LogsArgs.builder()
 *                     .autoEnable(true)
 *                     .build())
 *                 .kubernetes(OrganizationConfigurationDatasourcesKubernetesArgs.builder()
 *                     .auditLogs(OrganizationConfigurationDatasourcesKubernetesAuditLogsArgs.builder()
 *                         .enable(true)
 *                         .build())
 *                     .build())
 *                 .malwareProtection(OrganizationConfigurationDatasourcesMalwareProtectionArgs.builder()
 *                     .scanEc2InstanceWithFindings(OrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindingsArgs.builder()
 *                         .ebsVolumes(OrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumesArgs.builder()
 *                             .autoEnable(true)
 *                             .build())
 *                         .build())
 *                     .build())
 *                 .build())
 *             .build());
 *     }
 * }
 * ```
 * ```yaml
 * resources:
 *   example:
 *     type: aws:guardduty:Detector
 *     properties:
 *       enable: true
 *   exampleOrganizationConfiguration:
 *     type: aws:guardduty:OrganizationConfiguration
 *     name: example
 *     properties:
 *       autoEnableOrganizationMembers: ALL
 *       detectorId: ${example.id}
 *       datasources:
 *         s3Logs:
 *           autoEnable: true
 *         kubernetes:
 *           auditLogs:
 *             enable: true
 *         malwareProtection:
 *           scanEc2InstanceWithFindings:
 *             ebsVolumes:
 *               autoEnable: true
 * ```
 * <!--End PulumiCodeChooser -->
 * ## Import
 * Using `pulumi import`, import GuardDuty Organization Configurations using the GuardDuty Detector ID. For example:
 * ```sh
 * $ pulumi import aws:guardduty/organizationConfiguration:OrganizationConfiguration example 00b00fd5aecc0ab60a708659477e9617
 * ```
 * @property autoEnable *Deprecated:* Use `auto_enable_organization_members` instead. When this setting is enabled, all new accounts that are created in, or added to, the organization are added as a member accounts of the organization’s GuardDuty delegated administrator and GuardDuty is enabled in that AWS Region.
 * @property autoEnableOrganizationMembers Indicates the auto-enablement configuration of GuardDuty for the member accounts in the organization. Valid values are `ALL`, `NEW`, `NONE`.
 * @property datasources Configuration for the collected datasources.
 * @property detectorId The detector ID of the GuardDuty account.
 */
public data class OrganizationConfigurationArgs(
    @Deprecated(
        message = """
  Use auto_enable_organization_members instead
  """,
    )
    public val autoEnable: Output<Boolean>? = null,
    public val autoEnableOrganizationMembers: Output<String>? = null,
    public val datasources: Output<OrganizationConfigurationDatasourcesArgs>? = null,
    public val detectorId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.guardduty.OrganizationConfigurationArgs> {
    override fun toJava(): com.pulumi.aws.guardduty.OrganizationConfigurationArgs =
        com.pulumi.aws.guardduty.OrganizationConfigurationArgs.builder()
            .autoEnable(autoEnable?.applyValue({ args0 -> args0 }))
            .autoEnableOrganizationMembers(autoEnableOrganizationMembers?.applyValue({ args0 -> args0 }))
            .datasources(datasources?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .detectorId(detectorId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [OrganizationConfigurationArgs].
 */
@PulumiTagMarker
public class OrganizationConfigurationArgsBuilder internal constructor() {
    private var autoEnable: Output<Boolean>? = null

    private var autoEnableOrganizationMembers: Output<String>? = null

    private var datasources: Output<OrganizationConfigurationDatasourcesArgs>? = null

    private var detectorId: Output<String>? = null

    /**
     * @param value *Deprecated:* Use `auto_enable_organization_members` instead. When this setting is enabled, all new accounts that are created in, or added to, the organization are added as a member accounts of the organization’s GuardDuty delegated administrator and GuardDuty is enabled in that AWS Region.
     */
    @Deprecated(
        message = """
  Use auto_enable_organization_members instead
  """,
    )
    @JvmName("isxrdckpunvrujmb")
    public suspend fun autoEnable(`value`: Output<Boolean>) {
        this.autoEnable = value
    }

    /**
     * @param value Indicates the auto-enablement configuration of GuardDuty for the member accounts in the organization. Valid values are `ALL`, `NEW`, `NONE`.
     */
    @JvmName("ybvntebpsrwpjlyq")
    public suspend fun autoEnableOrganizationMembers(`value`: Output<String>) {
        this.autoEnableOrganizationMembers = value
    }

    /**
     * @param value Configuration for the collected datasources.
     */
    @JvmName("tbkqdldrvuxwtpas")
    public suspend fun datasources(`value`: Output<OrganizationConfigurationDatasourcesArgs>) {
        this.datasources = value
    }

    /**
     * @param value The detector ID of the GuardDuty account.
     */
    @JvmName("bmxtjkjuifsdvvwx")
    public suspend fun detectorId(`value`: Output<String>) {
        this.detectorId = value
    }

    /**
     * @param value *Deprecated:* Use `auto_enable_organization_members` instead. When this setting is enabled, all new accounts that are created in, or added to, the organization are added as a member accounts of the organization’s GuardDuty delegated administrator and GuardDuty is enabled in that AWS Region.
     */
    @Deprecated(
        message = """
  Use auto_enable_organization_members instead
  """,
    )
    @JvmName("vsxivbexjtvtbtka")
    public suspend fun autoEnable(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.autoEnable = mapped
    }

    /**
     * @param value Indicates the auto-enablement configuration of GuardDuty for the member accounts in the organization. Valid values are `ALL`, `NEW`, `NONE`.
     */
    @JvmName("nxixqrdyciegmtyv")
    public suspend fun autoEnableOrganizationMembers(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.autoEnableOrganizationMembers = mapped
    }

    /**
     * @param value Configuration for the collected datasources.
     */
    @JvmName("biucwgylscaugkyv")
    public suspend fun datasources(`value`: OrganizationConfigurationDatasourcesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.datasources = mapped
    }

    /**
     * @param argument Configuration for the collected datasources.
     */
    @JvmName("erskcjbknjngyhbx")
    public suspend fun datasources(argument: suspend OrganizationConfigurationDatasourcesArgsBuilder.() -> Unit) {
        val toBeMapped = OrganizationConfigurationDatasourcesArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.datasources = mapped
    }

    /**
     * @param value The detector ID of the GuardDuty account.
     */
    @JvmName("dffpbdcffjyirewv")
    public suspend fun detectorId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.detectorId = mapped
    }

    internal fun build(): OrganizationConfigurationArgs = OrganizationConfigurationArgs(
        autoEnable = autoEnable,
        autoEnableOrganizationMembers = autoEnableOrganizationMembers,
        datasources = datasources,
        detectorId = detectorId,
    )
}
